@@ -26,7 +26,6 @@
 #include <Lum/Button.h>
 #include <Lum/Dialog.h>
 #include <Lum/Panel.h>
-#include <Lum/Space.h>
 
 #include <Lum/Dlg/About.h>
 #include <Lum/Dlg/Msg.h>
@@ -96,51 +95,25 @@ public:
 
   void PreInit()
   {
-    Lum::Button      *button;
     Lum::Panel       *horiz,*vert;
 
-    horiz=new Lum::HPanel();
-    horiz->SetFlex(true,true);
+    horiz=Lum::HPanel::Create(true,true);
 
     control=new Control();
     control->SetFlex(true,true);
     horiz->Add(control);
     // TODO
 
-    horiz->Add(new Lum::HSpace());
+    horiz->AddSpace();
 
-    vert=new Lum::VPanel();
-    vert->SetFlex(false,true);
-
-    button=new Lum::Button;
-    button->SetFlex(true,false);
-    button->SetModel(newImageAction);
-    button->SetText(L"_New image");
-    vert->Add(button);
-
-    vert->Add(new Lum::VSpace());
-
-    button=new Lum::Button;
-    button->SetFlex(true,false);
-    button->SetModel(peekAction);
-    button->SetText(L"_Peek");
-    vert->Add(button);
-
-    vert->Add(new Lum::VSpace());
-
-    button=new Lum::Button;
-    button->SetFlex(true,false);
-    button->SetModel(blockGroupAction);
-    button->SetText(L"_Block group");
-    vert->Add(button);
-
-    vert->Add(new Lum::VSpace());
-
-    button=new Lum::Button;
-    button->SetFlex(true,false);
-    button->SetModel(imageInfoAction);
-    button->SetText(L"_Image info");
-    vert->Add(button);
+    vert=Lum::VPanel::Create(false,true);
+    vert->Add(Lum::Button::Create(L"_New image",newImageAction,true,false));
+    vert->AddSpace();
+    vert->Add(Lum::Button::Create(L"_Peek",peekAction,true,false));
+    vert->AddSpace();
+    vert->Add(Lum::Button::Create(L"_Block group",blockGroupAction,true,false));
+    vert->AddSpace();
+    vert->Add(Lum::Button::Create(L"_Image info",imageInfoAction,true,false));
 
     horiz->Add(vert);
 
